@@ -4,5 +4,5 @@ function (beta, x, y, scores)
     x <- as.matrix(x)
     e <- y - x %*% beta
     r <- rank(e, ties.method = "first")/(length(e) + 1)
-    scores@phi(r) %*% e
+    getScores(scores,r) %*% e
 }
