@@ -5,7 +5,7 @@ function (x, digits = max(5, .Options$digits - 2), ...)
     print(x$call)
     cat("\nCoefficients:\n")
     est <- x$coef
-    printCoefmat(x$coefficients, P.value = TRUE, has.Pvalue = TRUE)
+    printCoefmat(x$coefficients, P.values = TRUE, has.Pvalue = TRUE)
     cat("\nMultiple R-squared (Robust):", x$R2, "\n")
 #    cat("Wald Test:", round(x$waldstat, digits = digits), "p-value:", 
 #        round(x$waldpval, digits = digits), "\n")
